.. pynbody reference main index


.. _reference :

Pynbody reference documentation
===============================

The reference documentation for pynbody is largely generated automatically
from the source code. It is split into the following sections:


Core functionality
^^^^^^^^^^^^^^^^^^
.. autosummary::
   :toctree: _autosummary
   :recursive:

   pynbody.array
   pynbody.bridge
   pynbody.configuration
   pynbody.derived
   pynbody.filt
   pynbody.halo
   pynbody.snapshot
   pynbody.transformation
   pynbody.units

Scientific analysis
^^^^^^^^^^^^^^^^^^^
.. autosummary::
   :toctree: _autosummary
   :recursive:

   pynbody.analysis
   pynbody.gravity
   pynbody.plot

Low-level detail
^^^^^^^^^^^^^^^^
.. autosummary::
   :toctree: _autosummary
   :recursive:

   pynbody.chunk
   pynbody.dependencytracker
   pynbody.family
   pynbody.kdtree
   pynbody.openmp
   pynbody.simdict
   pynbody.sph
   pynbody.test_utils
   pynbody.util
